/****************************************************************************
 * Enumerations used in JWM.
 * Copyright (C) 2004 Joe Wingbermuehle
 ****************************************************************************/

#ifndef ENUM_H
#define ENUM_H

/****************************************************************************
 ****************************************************************************/
typedef enum {
	PROT_NONE       = 0,
	PROT_DELETE     = 1,
	PROT_TAKE_FOCUS = 2
} ClientProtocolType;

/****************************************************************************
 ****************************************************************************/
typedef enum {
	BORDER_NONE    = 0,
	BORDER_OUTLINE = 1,
	BORDER_TITLE   = 2,
	BORDER_MIN     = 4,
	BORDER_MAX     = 8,
	BORDER_CLOSE   = 16,
	BORDER_RESIZE  = 32,
	BORDER_MOVE    = 64
} BorderFlags;

/****************************************************************************
 ****************************************************************************/
typedef enum {
	STAT_NONE      = 0,
	STAT_ACTIVE    = 1 << 0,
	STAT_MAPPED    = 1 << 1,
	STAT_MAXIMIZED = 1 << 2,
	STAT_HIDDEN    = 1 << 3,
	STAT_STICKY    = 1 << 4,
	STAT_NOLIST    = 1 << 5,
	STAT_WITHDRAWN = 1 << 6,
	STAT_MINIMIZED = 1 << 7,
	STAT_SHADED    = 1 << 8,
	STAT_USESHAPE  = 1 << 9
} StatusFlags;

/****************************************************************************
 ****************************************************************************/
typedef enum {
	BA_NONE      = 0,
	BA_RESIZE    = 1,
	BA_MOVE      = 2,
	BA_CLOSE     = 3,
	BA_MAXIMIZE  = 4,
	BA_MINIMIZE  = 5,
	BA_RESIZE_N  = 0x10,
	BA_RESIZE_S  = 0x20,
	BA_RESIZE_E  = 0x40,
	BA_RESIZE_W  = 0x80
} BorderActionType;

/****************************************************************************
 ****************************************************************************/
typedef enum {
	TOK_INVALID,
	TOK_JWM,
	TOK_KEY,
	TOK_MENU,
	TOK_EXIT,
	TOK_RESTART,
	TOK_PROGRAM,
	TOK_TRAYFONT,
	TOK_MENUFONT,
	TOK_ROOTMENU,
	TOK_SEPARATOR,
	TOK_TEXTCOLOR,
	TOK_ANTIALIAS,
	TOK_BORDERFONT,
	TOK_BUTTONCOLOR,
	TOK_BORDERCOLOR,
	TOK_BORDERWIDTH,
	TOK_TITLEHEIGHT,
	TOK_DESKTOPCOUNT,
	TOK_ACTIVETEXTCOLOR,
	TOK_BUTTONTEXTCOLOR,
	TOK_DOUBLECLICKSPEED,
	TOK_DOUBLECLICKDELTA,
	TOK_ACTIVEBORDERCOLOR
} TokenType;


/****************************************************************************
 ****************************************************************************/
typedef enum {
	COLOR_BORDER = 0,
	COLOR_BORDER_TEXT = 1,
	COLOR_BORDER_OUTLINE = 2,
	COLOR_ACTIVE_BORDER = 3,
	COLOR_ACTIVE_BORDER_TEXT = 4,
	COLOR_BORDER_DOWN = 5,
	COLOR_BORDER_UP = 6,
	COLOR_ACTIVE_BORDER_DOWN = 7,
	COLOR_ACTIVE_BORDER_UP = 8,
	COLOR_BUTTON = 9,
	COLOR_BUTTON_TEXT = 10,
	COLOR_BUTTON_UP = 11,
	COLOR_BUTTON_DOWN = 12,
	COLOR_COUNT = 13
} ColorType;

/****************************************************************************
 ****************************************************************************/
typedef enum {
	BUTTON_INACTIVE,
	BUTTON_ACTIVE,
	BUTTON_MENU
} ButtonType;

/****************************************************************************
 ****************************************************************************/
typedef enum {
	ALIGN_LEFT,
	ALIGN_CENTER
} AlignmentType;

/****************************************************************************
 ****************************************************************************/
typedef enum {
	RAMP_INACTIVE = 0,
	RAMP_ACTIVE = 1,
	RAMP_BUTTON = 2,
	RAMP_COUNT = 3
} RampType;

/****************************************************************************
 ****************************************************************************/
typedef enum {
	WIN_STATE_STICKY          = 1 << 0,
	WIN_STATE_MINIMIZED       = 1 << 1,
	WIN_STATE_MAXIMIZED_VERT  = 1 << 2,
	WIN_STATE_MAXIMIZED_HORIZ = 1 << 3,
	WIN_STATE_HIDDEN          = 1 << 4,
	WIN_STATE_SHADED          = 1 << 5,
	WIN_STATE_HIDE_WORKSPACE  = 1 << 6,
	WIN_STATE_HIDE_TRANSIENT  = 1 << 7,
	WIN_STATE_FIXED_POSITION  = 1 << 8,
	WIN_STATE_ARRANGE_IGNORE  = 1 << 9,
} WinStateType;

/****************************************************************************
 ****************************************************************************/
typedef enum {
	WIN_HINT_SKIP_FOCUS       = 1 << 0,
	WIN_HINT_SKIP_WINLIST     = 1 << 1,
	WIN_HINT_SKIP_TASKBAR     = 1 << 2,
	WIN_HINT_GROUP_TRANSIENT  = 1 << 3,
	WIN_HINT_FOCUS_ON_CLICK   = 1 << 4
} WinHintType;

/****************************************************************************
 ****************************************************************************/
typedef enum {
	LAYER_BOTTOM              = 0,
	LAYER_NORMAL              = 4,
	LAYER_TRAY                = 8,
	LAYER_TOP                 = 12
} WinLayerType;

/****************************************************************************
 * Note: extra information about the key press is stored << 8.
 * (For example, a grab of '#' will grab any number key 1-9 and pass
 * the offset (1-9) in the upper byte).
 ****************************************************************************/
typedef enum {
	KEY_NONE    = 0,
	KEY_UP      = 1,
	KEY_DOWN    = 2,
	KEY_RIGHT   = 3,
	KEY_LEFT    = 4,
	KEY_ESC     = 5,
	KEY_ENTER   = 6,
	KEY_NEXT    = 7,
	KEY_CLOSE   = 8,
	KEY_MIN     = 9,
	KEY_MAX     = 10,
	KEY_SHADE   = 11,
	KEY_MOVE    = 12,
	KEY_RESIZE  = 13,
	KEY_ROOT    = 14,
	KEY_WIN     = 15,
	KEY_DESKTOP = 16
} KeyType;

#endif

